# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   python_test
# FileName:      read_excel.py
# Author:       xxxxxxx
# Datetime:     2023/11/4 11:26
# Description:
# 命名规范：文件名全小写+下划线，类名大驼峰，方法和变量小写+下划线连接，
# 常量大写，变量和常量用名词，方法用动词
# ---------------------------------------------------------------------------
import os

import openpyxl

from InterfaceAutoTest01.common import log
from InterfaceAutoTest01.common.read_ini import ReadIni
from InterfaceAutoTest01.common.read_json import read_json


class ReadExcel:
    def __init__(self, table_name, testers_name):
        self.read_ini = ReadIni()
        # excel_path = self.read_ini.get_file("excel")
        # case_path = self.read_ini.get_file("case")
        # expect_path = self.read_ini.get_file("expect")
        # sql_path = self.read_ini.get_file("sql")
        # table_name = self.read_ini.get_table("table_name")

        data_path = os.path.join(self.read_ini.data_path, testers_name)

        excel_path = os.path.join(data_path, "APIAutoTest.xlsx")
        if not os.path.isfile(excel_path):
            log.error("获取文件不合法，请查看文件路径或data_config文件夹内文件是否正确")
            raise FileNotFoundError("获取文件不合法，请查看文件路径或data_config文件夹内文件是否正确")
        case_path = os.path.join(data_path, "case_data.json")
        expect_path = os.path.join(data_path, "expect_data.json")
        sql_path = os.path.join(data_path, "sql_data.json")

        try:
            wb = openpyxl.load_workbook(excel_path)
            self.ws = wb[table_name]
        except:
            log.error("打开excel表失败，请查看excel表工作表名是否正确")
            raise KeyError("打开excel表失败，请查看excel表工作表名是否正确")
        self.case_data_dict = read_json(case_path)
        self.expect_data_dict = read_json(expect_path)
        self.sql_data_dict = read_json(sql_path)

    def __get_excel_value(self, column, row):
        """根据工作表的行和列获取单元格数据"""
        try:
            value = self.ws[column+str(row)].value
            if value is None:
                return None
            elif value.strip():
                return value.strip()
        except:
            log.error("获取指定单元格数据失败，请察看输入的列号和行号是否正确！！")
            raise KeyError("获取指定单元格数据失败，请察看输入的列号和行号是否正确！！")

    def get_module_name(self, row):
        """根据行号获取模块模块名称"""
        return self.__get_excel_value("b", row)

    def get_api_name(self, row):
        """根据行号获取接口名称"""
        return self.__get_excel_value("c", row)

    def get_title(self, row):
        """根据行号获取用例名称"""
        return self.__get_excel_value("d", row)

    def get_level(self, row):
        """根据行号，获取用例等级"""
        return self.__get_excel_value("e", row)

    def get_url(self, row):
        """根据行号获取url"""
        host = self.read_ini.get_host("host")
        return os.path.join(host + self.__get_excel_value("f", row))

    def get_method(self, row):
        """根据行号获取请求方式"""

        value = self.__get_excel_value("g", row)
        if value:
            return value.upper()

    def get_mime(self, row):
        """根据行号获取传参方式"""
        value = self.__get_excel_value("h", row)
        if value:
            return value.lower()

    def get_case_data(self, row):
        """根据行号获取用例数据"""
        case_key = self.__get_excel_value("i", row)
        if case_key:
            module_name = self.get_module_name(row)
            api_name = self.get_api_name(row)
            return self.case_data_dict[module_name][api_name][case_key]

    def get_expect_data(self, row):
        """根据行号获取期望数据"""
        expect_key = self.__get_excel_value("j", row)
        if expect_key:
            module_name = self.get_module_name(row)
            api_name = self.get_api_name(row)
            return self.expect_data_dict[module_name][api_name][expect_key]

    def get_sql_type(self, row):
        """根据行号获取sql语句类型"""
        value = self.__get_excel_value("k", row)
        if value:
            return value.lower()

    def get_sql_data(self, row):
        """根据行号获取sql语句"""
        sql_key = self.__get_excel_value("l", row)
        if sql_key:
            module_name = self.get_module_name(row)
            api_name = self.get_api_name(row)
            return self.sql_data_dict[module_name][api_name][sql_key]

    def get_update_key(self, row):
        return self.__get_excel_value("m", row)

    def all_data(self):
        """获取所有需要的数据存在一个二维列表中，并返回"""
        list_data = []
        for row in range(2, self.ws.max_row + 1):
            module_name = self.get_module_name(row)
            api_name = self.get_api_name(row)
            title = self.get_title(row)
            level = self.get_level(row)
            url = self.get_url(row)
            method = self.get_method(row)
            mime = self.get_mime(row)
            case_data = self.get_case_data(row)
            expect_data = self.get_expect_data(row)
            sql_type = self.get_sql_type(row)
            sql_data = self.get_sql_data(row)
            update_key = self.get_update_key(row)
            list_data.append([row, module_name, api_name, title, level, url, method, mime, case_data, expect_data, sql_type, sql_data, update_key])
        return list_data


if __name__ == '__main__':
    r = ReadExcel("BPM", "hexi")
# D:\hexi\python_test\InterfaceAutoTest01\data_config\hexi\APIAutoTest.xlsx
# D:\hexi\python_test\InterfaceAutoTest01\data_config\hexi\APIAutoTest.xlsx
# D:\hexi\python_test\InterfaceAutoTest01\data_config\hexi\case_data.json
# D:\hexi\python_test\InterfaceAutoTest01\data_config\hexi\expect_data.json
# D:\hexi\python_test\InterfaceAutoTest01\data_config\hexi\sql_data.json


