# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   python_test
# FileName:      read_ini.py
# Author:       xxxxxxx
# Datetime:     2023/11/4 10:14
# Description:
# 命名规范：文件名全小写+下划线，类名大驼峰，方法和变量小写+下划线连接，
# 常量大写，变量和常量用名词，方法用动词
# ---------------------------------------------------------------------------
import configparser
import os
from InterfaceAutoTest01.common import log


class ReadIni:
    def __init__(self):
        self.data_path = os.path.join(os.path.dirname(os.path.dirname(__file__)), "data_config")
        config_path = os.path.join(self.data_path, "config.ini")
        self.conf = configparser.ConfigParser()
        self.conf.read(config_path, encoding="utf-8")

    def get_file(self, key):
        """根据key获取file节点下的值"""
        try:
            file_path = os.path.join(self.data_path, self.conf.get("file", key))
        except:
            log.error("获取配置文件file节点下值错误，请查看配置文件或传入key是否正确")
            raise KeyError("获取配置文件file节点下值错误，请查看配置文件或传入key是否正确")

        if os.path.isfile(file_path):
            return file_path
        else:
            log.error("获取文件不合法，请查看配置文件file节点下key或data_config文件夹内文件是否正确")
            raise FileNotFoundError("获取文件不合法，请查看配置文件file节点下key或data_config文件夹内文件是否正确")

    def get_host(self, key):
        """根据key获取table节点下的值"""
        try:
            return self.conf.get("host", key)
        except:
            log.error("获取配置文件host节点下值错误，请查看配置文件或传入key是否正确")
            raise KeyError("获取配置文件host节点下值错误，请查看配置文件或传入key是否正确")

    def get_table(self, key):
        """根据key获取table节点下的值"""
        try:
            return self.conf.get("table", key)
        except:
            log.error("获取配置文件table节点下值错误，请查看配置文件或传入key是否正确")
            raise KeyError("获取配置文件table节点下值错误，请查看配置文件或传入key是否正确")

    def get_sql(self, key):
        """根据key获取sql节点下的值"""
        try:
            return self.conf.get("sql", key)
        except:
            log.error("获取配置文件sql节点下值错误，请查看配置文件或传入key是否正确")
            raise KeyError("获取配置文件sql节点下值错误，请查看配置文件或传入key是否正确")

    def get_login_url(self, key):
        try:
            return self.get_host("host") + self.conf.get("login", key)
        except:
            log.error("获取配置文件login节点下值错误，请查看配置文件或传入key是否正确")
            raise KeyError("获取配置文件login节点下值错误，请查看配置文件或传入key是否正确")


if __name__ == '__main__':
    r = ReadIni()
    print(r.get_table("table_name"))
    print(r.get_sql("host"))
    print(r.get_file("excel"))
    print(r.get_host("host"))
    print(r.get_login_url("address"))
#D:\hexi\python_test\InterfaceAutoTest01\data_config\APIAutoTest1.xlsx
#D:\hexi\python_test\InterfaceAutoTest01\data_config\APIAutoTest1.xlsx
